# eric7.Debugger.EditWatchpointDialog

Module implementing a dialog to edit watch expression properties.

### Global Attributes

None

### Classes

EditWatchpointDialog | Class implementing a dialog to edit watch expression properties.

### Functions

None

## EditWatchpointDialog

Class implementing a dialog to edit watch expression properties.

### Derived from

QDialog, Ui_EditWatchpointDialog

### Class Attributes

None

### Class Methods

None

### Methods

EditWatchpointDialog | Constructor
__textChanged | Private slot to handle the text changed signal of the condition line edit.
getData | Public method to retrieve the entered data.

### Static Methods

None

#### EditWatchpointDialog (Constructor)

EditWatchpointDialog(properties, parent=None, name=None, modal=False)

Constructor

properties (tuple of (str, bool, bool, int, str))
  properties for the watch expression (expression, temporary flag, enabled flag, ignore count, special condition)
parent (QWidget)
  the parent of this dialog
name (str)
  the widget name of this dialog
modal (bool)
  flag indicating a modal dialog

#### EditWatchpointDialog.__textChanged

__textChanged(_txt)

Private slot to handle the text changed signal of the condition line edit.

_txt (str)
  text of the line edit (unused)

#### EditWatchpointDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  a tuple containing the watch expressions new properties (expression, temporary flag, enabled flag, ignore count, special condition)

Return Type:
  tuple of (str, bool, bool, int, str)

Up